@@ -13,10 +13,12 @@ from string import Template
 from subprocess import CompletedProcess, run
 from tempfile import TemporaryDirectory
 from typing import Dict, List, Tuple, Union
-from azureml.assets.config import AssetConfig, AssetType, ComponentType, ModelConfig
+from azureml.assets.config import AssetConfig, AssetType, ComponentType, ModelConfig, DataConfig
 from azureml.assets.deployment_config import AssetVersionUpdate
-from azureml.assets.model.model_utils import CopyUpdater, prepare_model, update_model_metadata
+from azureml.assets.model.registry_utils import CopyUpdater, prepare_model, update_metadata, \
+    prepare_data, RegistryUtils
 from azureml.assets.util import logger
+from azureml.assets.util.util import resolve_from_file_for_asset
 from azure.ai.ml import MLClient
 from azure.ai.ml.entities import Component, Environment, Model
 from ruamel.yaml import YAML
@@ -30,14 +32,6 @@ BEARER = r"Bearer.*"
 LATEST_LABEL = "latest"
 
 
-def pluralize_asset_type(asset_type: Union[AssetType, str]) -> str:
-    """Return pluralized asset type."""
-    # Convert to string if enum
-    if isinstance(asset_type, AssetType):
-        asset_type = asset_type.value
-    return f"{asset_type}s" if asset_type != "data" else asset_type
-
-
 def sanitize_output(input: str) -> str:
     """Return sanitized string."""
     # Remove sensitive token
@@ -48,7 +42,7 @@ def sanitize_output(input: str) -> str:
 def update_spec(asset: Union[Component, Environment, Model], spec_path: Path) -> bool:
     """Update the yaml spec file with updated properties in asset.
 
-    :param asset: Asset loaded using load_*(component, environemnt, model) method.
+    :param asset: Asset loaded using load_*(component, environment, model) method.
     :type asset: Union[Component, Environment, Model]
     :param spec_path: path to asset spec file
     :type spec_path: Path
@@ -70,6 +64,7 @@ def prepare_model_for_registration(
     temp_dir: Path,
     ml_client: MLClient,
     copy_updater: CopyUpdater = None,
+    output_level: str = "essential",
 ) -> bool:
     """Prepare model.
 
@@ -83,12 +78,14 @@ def prepare_model_for_registration(
     :type ml_client: MLClient
     :param copy_updater: CopyUpdater object to update files during azcopy
     :type copy_updater: CopyUpdater
+    :param output_level: Parameter for azcopy output verbosity level
+    :type output_level: str
     :return: Model successfully prepared for creation in registry.
     :rtype: bool
     """
     model, success = prepare_model(
         spec_path=spec_file_path, model_config=model_config, temp_dir=temp_dir, ml_client=ml_client,
-        copy_updater=copy_updater
+        copy_updater=copy_updater, output_level=output_level
     )
     if success:
         success = update_spec(model, spec_file_path)
@@ -96,6 +93,41 @@ def prepare_model_for_registration(
     return success
 
 
+def prepare_data_for_registration(
+    data_config: DataConfig,
+    spec_file_path: Path,
+    temp_dir: Path,
+    ml_client: MLClient,
+    copy_updater: CopyUpdater = None,
+    output_level: str = "essential",
+) -> bool:
+    """Prepare data.
+
+    :param data_config: Data Config object
+    :type data_config: DataConfig
+    :param spec_file_path: path to data spec file
+    :type spec_file_path: Path
+    :param temp_dir: temp dir for data operation
+    :type temp_dir: Path
+    :param ml_client: MLClient object
+    :type ml_client: MLClient
+    :param copy_updater: CopyUpdater object to update files during azcopy
+    :type copy_updater: CopyUpdater
+    :param output_level: Parameter for azcopy output verbosity level
+    :type output_level: str
+    :return: Data successfully prepared for creation in registry.
+    :rtype: bool
+    """
+    data, success = prepare_data(
+        spec_path=spec_file_path, data_config=data_config, temp_dir=temp_dir, ml_client=ml_client,
+        copy_updater=copy_updater, output_level=output_level
+    )
+    if success:
+        success = update_spec(data, spec_file_path)
+        logger.print(f"updated spec file? {success}")
+    return success
+
+
 def validate_and_prepare_pipeline_component(
     spec_path: Path,
     registry_name: str,
@@ -419,7 +451,7 @@ def get_parsed_details_from_asset_uri(asset_type: str, asset_uri: str) -> Tuple[
     :rtype: Tuple
     """
     REGISTRY_ASSET_PATTERN = re.compile(REGISTRY_ASSET_TEMPLATE.substitute(
-                                        asset_type=pluralize_asset_type(asset_type)))
+                                        asset_type=RegistryUtils.pluralize_asset_type(asset_type)))
     asset_registry_name = None
     if (match := REGISTRY_ASSET_PATTERN.match(asset_uri)) is not None:
         asset_registry_name, asset_name, asset_version, asset_label = match.groups()
@@ -440,38 +472,45 @@ def stringify_dictionary(dictionary: Dict):
 
 def update_asset_metadata(asset: AssetConfig, ml_client: MLClient, allow_no_op_update: bool = False):
     """Update the mutable metadata of asset."""
-    if asset.type == AssetType.MODEL:
-        model_name = asset.name
-        model_version = asset.version
+    if asset.type in [AssetType.COMPONENT, AssetType.DATA, AssetType.MODEL]:
+        asset_name = asset.name
+        asset_version = asset.version
         spec_path = asset.spec_with_path
-        model_config = asset.extra_config_as_object()
 
-        # get tags to update from model spec file
         tags_to_update = None
         try:
             with open(spec_path) as f:
-                model_spec = YAML().load(f)
-                tags = model_spec.get("tags", {})
-                properties = model_spec.get("properties", {})
+                asset_spec = YAML().load(f)
+                tags = asset_spec.get("tags", {})
+                properties = asset_spec.get("properties", {})
+
+                if asset.type == AssetType.MODEL:
+                    model_config = asset.extra_config_as_object()
+                    tags = {k: resolve_from_file_for_asset(model_config, v) for k, v in tags.items()}
+                    description = model_config.description
 
                 # convert tags, properties value to string
                 tags = stringify_dictionary(tags)
                 properties = stringify_dictionary(properties)
                 tags_to_update = {"replace": tags}
                 properties_to_update = {"add": properties}
-        except Exception as e:
-            logger.log_error(f"Failed to get tags for model {model_name}: {e}")
 
-        update_model_metadata(
-            model_name=model_name,
-            model_version=model_version,
+                if asset.type in [AssetType.COMPONENT, AssetType.DATA]:
+                    description = asset_spec.get("description", None)
+        except Exception as e:
+            logger.log_error(f"Failed to get tags for {asset.type.value} {asset_name}: {e}")
+
+        update_metadata(
+            name=asset_name,
+            version=asset_version,
             update=AssetVersionUpdate(
-                versions=[model_version],
+                versions=[asset_version],
                 tags=tags_to_update,
                 properties=properties_to_update,
-                description=model_config.description
+                description=description
             ),
             ml_client=ml_client,
+            asset_type=asset.type,
             allow_no_op_update=allow_no_op_update,
         )
     else:
@@ -479,7 +518,7 @@ def update_asset_metadata(asset: AssetConfig, ml_client: MLClient, allow_no_op_u
 
 
 def create_asset(asset: AssetConfig, registry_name: str, ml_client: MLClient, version_template: str = None,
-                 debug: bool = None, copy_updater: CopyUpdater = None) -> bool:
+                 debug: bool = None, copy_updater: CopyUpdater = None, output_level: str = "essential") -> bool:
     """Create asset or update model metadata if it already exists.
 
     Args:
@@ -489,6 +528,7 @@ def create_asset(asset: AssetConfig, registry_name: str, ml_client: MLClient, ve
         version_template (str, optional): Version template. Defaults to None.
         debug (bool, optional): Enable debug logging. Defaults to None.
         copy_updater (CopyUpdater, optional): CopyUpdater object to update files during azcopy. Defaults to None.
+        output_level (str, optional): Output verbosity level parameter for azcopy. Defaults to "essential".
 
     Returns:
         bool: True of successfully create/updated, otherwise False.
@@ -521,11 +561,18 @@ def create_asset(asset: AssetConfig, registry_name: str, ml_client: MLClient, ve
                     return False
         elif asset.type == AssetType.MODEL:
             version = asset.version
-            model_config = asset.extra_config_as_object()
+            model_config: ModelConfig = asset.extra_config_as_object()
             if not prepare_model_for_registration(model_config, asset.spec_with_path, Path(temp_dir), ml_client,
-                                                  copy_updater):
+                                                  copy_updater, output_level):
                 logger.log_error("Failed to prepare model")
                 return False
+        elif asset.type == AssetType.DATA:
+            version = asset.version
+            data_config: DataConfig = asset.extra_config_as_object()
+            if not prepare_data_for_registration(data_config, asset.spec_with_path, Path(temp_dir), ml_client,
+                                                 copy_updater, output_level):
+                logger.log_error("Failed to prepare data asset")
+                return False
 
         # Create asset
         return create_asset_cli(
