@@ -16,6 +16,7 @@ from typing import List
 from azure.ai.ml import load_model
 from azure.ai.ml.entities import Model
 from azure.ai.ml.operations._run_history_constants import JobStatus
+from azure.core.exceptions import ClientAuthenticationError
 from azure.identity import AzureCliCredential
 
 import azureml.assets as assets
@@ -32,6 +33,7 @@ WARNING_TEMPLATE = "Warning during validation of {file}: {warning}"
 NAMING_CONVENTION_URL = "https://github.com/Azure/azureml-assets/wiki/Asset-naming-convention"
 INVALID_STRINGS = [["azureml", "azure"], "aml"]  # Disallow these in any asset name
 NON_MODEL_INVALID_STRINGS = ["microsoft"]  # Allow these in model names and other assets related to models
+MODEL_NAMES_VALIDATION_OVERRIDE_PREFIX = ["Azure-AI-"]  # Exception for Azure-AI models
 MODEL_RELATED_ASSETS = [assets.AssetType.MODEL, assets.AssetType.EVALUATIONRESULT]
 NON_MODEL_NAME_PATTERN = re.compile(r"^[a-z][a-z0-9_.-]{0,254}$")
 
@@ -47,17 +49,6 @@ VALIDATION_SUMMARY = "results.json"
 SUPPORTED_INFERENCE_SKU_FILE_NAME = "config/supported_inference_skus.json"
 SUPPORTED_INFERENCE_SKU_FILE_PATH = Path(__file__).parent / SUPPORTED_INFERENCE_SKU_FILE_NAME
 
-# credential and mlcient initialization
-# credential might not always be present
-# check in try-except block
-credential = None
-try:
-    credential = AzureCliCredential()
-    token = credential.get_token("https://management.azure.com/.default")
-except Exception as e:
-    credential = None
-    logger.log_warning(f"Exception in creating credential. {e}")
-
 
 class MLFlowModelProperties:
     """Commonly defined model properties."""
@@ -397,6 +388,9 @@ def validate_name(asset_config: assets.AssetConfig) -> int:
 
         for invalid_string in string_group_list:
             if invalid_string in asset_name_lowercase:
+                if (asset_config.type == assets.AssetType.MODEL and
+                        any(asset_name.startswith(exception) for exception in MODEL_NAMES_VALIDATION_OVERRIDE_PREFIX)):
+                    continue
                 # Complain only about the first matching string
                 _log_error(asset_config.file_name_with_path,
                            f"Name '{asset_name}' contains invalid string '{invalid_string}'")
@@ -755,13 +749,13 @@ def confirm_min_sku_spec(
     Returns:
         int: Number of errors.
     """
-    subscription_id = os.getenv("SUBSCRIPTION_ID", None)
-    if not (credential and subscription_id):
-        logger.log_warning("credential or subscription_id missing. Skipping min sku valdn")
+    subscription_id = os.getenv("SUBSCRIPTION_ID")
+    if not subscription_id:
+        logger.log_warning("subscription_id missing. Skipping min sku valdn")
         return 0
 
     try:
-        all_sku_details = get_all_sku_details(credential, subscription_id)
+        all_sku_details = get_all_sku_details(AzureCliCredential(), subscription_id)
         min_disk = min_cpu_mem = min_ngpus = min_ncpus = -1
         for sku in supported_skus:
             sku_details = all_sku_details.get(sku)
@@ -809,8 +803,10 @@ def confirm_min_sku_spec(
             )
 
             return 1
+    except ClientAuthenticationError as e:
+        logger.log_warning(f"Failed to log in to Azure, skipping min sku valdn. {e}")
     except Exception as e:
-        _log_error(asset_file_name_with_path, f"Exception in fetching SKU details => {e}")
+        _log_error(asset_file_name_with_path, f"Exception in fetching SKU details: {e}")
         return 1
     return 0
 
@@ -1081,10 +1077,17 @@ def validate_assets(input_dirs: List[Path],
                 asset_spec = asset_config._spec._yaml
                 evaluation_type = asset_spec.get('tags', {}).get('evaluation_type', None)
 
-                if evaluation_type == 'text_generation':
-                    error_count += validate_tags(asset_config, 'evaluationresult/tag_values_text_generation.yaml')
-                elif evaluation_type == 'text_embeddings':
-                    error_count += validate_tags(asset_config, 'evaluationresult/tag_values_text_embeddings.yaml')
+                evaluation_tag_files = {
+                    'text_generation': 'evaluationresult/tag_values_text_generation.yaml',
+                    'text_embeddings': 'evaluationresult/tag_values_text_embeddings.yaml',
+                    'vision': 'evaluationresult/tag_values_vision.yaml',
+                    'text_quality': 'evaluationresult/tag_values_text_quality.yaml',
+                    'text_performance': 'evaluationresult/tag_values_text_performance.yaml',
+                    'text_cost': 'evaluationresult/tag_values_text_cost.yaml'
+                }
+
+                if evaluation_type in evaluation_tag_files:
+                    error_count += validate_tags(asset_config, evaluation_tag_files[evaluation_type])
                 else:
                     _log_error(
                         asset_config.file_name_with_path,
